@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2009 Jeffrey Stedfast
+ *  Copyright (C) 2000-2011 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,6 @@
 #ifndef __GMIME_STREAM_FS_H__
 #define __GMIME_STREAM_FS_H__
 
-#include <unistd.h>
 #include <gmime/gmime-stream.h>
 
 G_BEGIN_DECLS
@@ -37,6 +36,15 @@ G_BEGIN_DECLS
 typedef struct _GMimeStreamFs GMimeStreamFs;
 typedef struct _GMimeStreamFsClass GMimeStreamFsClass;
 
+/**
+ * GMimeStreamFs:
+ * @parent_object: parent #GMimeStream
+ * @owner: %TRUE if this stream owns @fd
+ * @eos: %TRUE if end-of-stream
+ * @fd: file descriptor
+ *
+ * A #GMimeStream wrapper around POSIX file descriptors.
+ **/
 struct _GMimeStreamFs {
 	GMimeStream parent_object;
 	
@@ -54,7 +62,7 @@ struct _GMimeStreamFsClass {
 GType g_mime_stream_fs_get_type (void);
 
 GMimeStream *g_mime_stream_fs_new (int fd);
-GMimeStream *g_mime_stream_fs_new_with_bounds (int fd, off_t start, off_t end);
+GMimeStream *g_mime_stream_fs_new_with_bounds (int fd, gint64 start, gint64 end);
 
 gboolean g_mime_stream_fs_get_owner (GMimeStreamFs *stream);
 void g_mime_stream_fs_set_owner (GMimeStreamFs *stream, gboolean owner);
